@@ -1,6 +1,6 @@
 package Map::Tube::London::Line::Circle;
 
-$Map::Tube::London::Line::Circle::VERSION = '0.27';
+$Map::Tube::London::Line::Circle::VERSION = '0.28';
 
 =head1 NAME
 
@@ -8,7 +8,7 @@ Map::Tube::London::Line::Circle - London Tube Map Circle Line stations.
 
 =head1 VERSION
 
-Version 0.27
+Version 0.28
 
 =head1 DESCRIPTION
 
@@ -74,18 +74,24 @@ London Tube Map Circle Line stations.
 =item * The station "Paddington" is also part of L<Bakerloo Line|Map::Tube::London::Line::Bakerloo>
         | L<District Line|Map::Tube::London::Line::District>.
 
-=item * The station "Moorgate" is also part of Northern Line.
+=item * The station "Moorgate" is also part of L<Hammersmith & City Line|Map::Tube::London::Line::HammersmithCity>
+        | L<Metropolitan Line|Map::Tube::London::Line::Metropolitan>
+        | Northern Line.
 
-=item * The station "King's Cross St Pancras" is also part of Northern Line | Picadilly Line |
-        Victoria Line.
+=item * The station "King's Cross St Pancras" is also part of L<Hammersmith & City Line|Map::Tube::London::Line::HammersmithCity>
+        | L<Metropolitan Line|Map::Tube::London::Line::Metropolitan>
+        | Northern Line
+        | Picadilly Line
+        | Victoria Line.
 
 =item * The station "Liverpool Street" is also part of L<Central Line|Map::Tube::London::Line::Central>
-        | L<Hammersmith & City Line|Map::Tube::London::Line::HammersmithCity>.
+        | L<Hammersmith & City Line|Map::Tube::London::Line::HammersmithCity>
+        | L<Metropolitan Line|Map::Tube::London::Line::Metropolitan>.
 
 =item * The station "Baker Street" is also part of L<Hammersmith & City Line|Map::Tube::London::Line::HammersmithCity>
         | L<Jubilee Line|Map::Tube::London::Line::Jubilee>
         | L<Bakerloo Line|Map::Tube::London::Line::Bakerloo>
-        | Metropolitan Line.
+        | L<Metropolitan Line|Map::Tube::London::Line::Metropolitan>.
 
 =back
 
